
#line 3 "lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 236
#define YY_END_OF_BUFFER 237
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[773] =
    {   0,
       44,   44,   44,   44,    0,    0,   82,   82,   92,   92,
       85,   85,   60,   60,    0,    0,   74,   74,    0,    0,
        0,    0,  237,  235,   44,    1,    2,  235,  235,  235,
      235,  233,   42,   49,   41,  234,  234,  234,  234,  234,
      234,  234,  234,  234,  234,  234,  234,  234,  234,  234,
      234,  234,  234,  234,  234,   53,  235,   44,  231,  234,
      236,   44,    2,  236,  236,  236,   49,   59,   59,   59,
       59,   59,   59,   59,   59,   53,  236,   81,   81,    2,
       81,   84,   82,    2,   83,   84,   92,  216,  215,  236,
      236,  236,  236,  236,  236,  236,  236,  217,   89,   85,

        2,   87,   88,   86,   89,   66,   60,    2,   63,   65,
       64,   66,   66,   71,   71,    2,   71,   71,   71,   71,
       74,   80,   77,  236,  236,  236,  232,  232,    2,  232,
       91,   91,    2,   90,   91,   44,    0,    0,   48,   43,
        0,   47,    0,   46,   49,  234,  234,  234,  234,  234,
       45,  234,  234,   50,  234,   37,  234,  234,  234,  234,
      234,  234,  234,  234,  234,  234,  234,  234,  234,  234,
      234,  234,  234,  234,    0,  234,  234,  234,   51,    0,
      218,    0,   44,    0,   43,  231,   43,   45,  223,  222,
       44,    0,   59,   59,   50,   59,   56,   59,   59,   51,

        0,   82,   92,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   85,   60,    0,
        0,    0,   68,   67,    0,    0,   70,    0,   69,    0,
       73,   72,   74,   77,    0,   78,   79,    0,  227,  226,
       29,  234,  234,  234,  234,  234,  234,  234,  234,  234,
      234,  234,  234,  234,  234,  234,  234,  234,  234,  234,
      234,  234,  234,   35,  234,  234,  234,  234,  234,  234,
       52,   27,  234,  234,  234,  219,  228,  231,  231,  231,
        0,  225,  224,   59,   59,   58,   59,  103,    0,    0,
        0,  106,  107,  108,  109,  110,  111,  112,  113,  114,

      115,  116,  117,  118,  119,  120,  121,  122,  123,  124,
      125,  126,  127,  128,  129,  130,  131,  132,  133,  134,
      135,  136,  137,  138,  139,  140,  141,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   62,   61,    0,
        0,   76,   75,    0,    0,  234,   31,  234,  234,   39,
      234,  234,  234,  234,  234,  234,  234,  234,  234,  234,
      234,  234,  234,  234,    3,  234,  234,   24,  234,  234,
      234,  234,  234,  234,  234,  234,  231,  231,   54,   59,
       57,    0,   94,    0,  102,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  183,  184,  185,  186,  187,

      188,  189,  190,  191,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  160,   96,    0,    0,    0,  100,    0,
        0,    0,  213,    0,   67,    0,    0,  220,    0,  234,
       22,  234,    0,  234,  234,  234,  234,  234,  234,   25,
      234,   32,  234,  234,  234,   34,  234,  234,  234,  234,
      234,  234,   23,  234,  234,  234,  234,  234,  231,  230,
       59,  100,    0,  210,  214,  214,  214,  214,  214,  214,
      211,  214,  165,  214,  214,  157,  192,  193,  194,  195,
      196,  197,  198,  199,  200,  201,  202,  203,  204,  205,

      206,  214,  214,  166,  214,  214,  173,  174,  175,  176,
      177,  178,  179,  180,  181,  182,  214,  214,  214,  214,
      214,  212,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  153,   95,    0,   98,   99,    0,  101,
        0,   68,   67,  221,   16,    0,    4,    0,    0,  234,
      234,  234,  234,  234,  234,    5,  234,  234,    8,  234,
      234,  234,   30,   38,    0,  234,   40,  234,    0,  234,
      234,  231,  230,   59,    0,  214,  214,  152,  209,  214,
      214,  214,  162,  214,  214,  158,  214,  214,  159,  214,
      214,  214,  214,  214,  214,  214,  214,  164,  163,  214,

      214,  214,  214,  214,  214,  214,   93,   97,   68,    0,
        0,    4,    4,    0,    0,  234,    0,  234,   28,  234,
       36,  234,  234,  234,   13,  234,   33,    0,  234,   17,
        0,    6,  234,  229,   55,  102,  214,  214,  147,  143,
      214,  154,  148,  214,  149,  171,  214,  214,  214,  214,
      214,  155,  214,  105,  151,  161,  214,  207,  146,  104,
        0,    0,    0,    0,  234,  234,  234,  234,  234,    7,
      234,    0,  234,    0,  234,  229,  214,  214,  214,  144,
      214,  169,  214,  168,  214,  145,  156,    0,    0,    0,
        0,  234,  234,   12,  234,  234,    0,  234,    0,  234,

        0,  234,  142,  150,  208,  170,  172,  167,   20,    0,
        0,    0,  234,   10,  234,  234,    0,  234,    0,  234,
       26,  234,    0,    0,   10,    0,  234,    0,  234,  234,
        0,  234,    0,    0,  234,  234,    0,    0,  234,    0,
      234,  234,    0,  234,    0,  234,  234,   21,    0,    9,
        0,  234,  234,    0,  234,    0,  234,  234,    9,    0,
       15,  234,    0,   14,    0,   11,   18,   15,   19,   14,
       11,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    1,    7,    1,    1,    8,    9,
       10,    1,   11,   12,    1,   13,    1,   14,   15,   16,
       17,   18,   19,   20,   21,   22,   23,   24,    1,    1,
        1,   25,    1,    1,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   37,   38,   39,   40,   41,
       42,   43,   44,   45,   46,   47,   48,   49,   50,   51,
       52,   53,   54,    1,   55,    1,   56,   57,   58,   59,

       60,   61,   62,   63,   64,   65,   66,   67,   68,   69,
       70,   71,   72,   73,   74,   75,   76,   77,   78,   79,
       80,   81,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[82] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    4,    1,    3,    3,    3,    3,    3,
        3,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    1,    1,    1,    1,    3,    3,    3,    3,    3,
        3,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5
    } ;

static const flex_int16_t yy_base[801] =
    {   0,
        0,   77,  135,    0,  215,  219,  223,  227,  279,  357,
      236,  247,  435,  492,  258,  289,  549,    0,  322,  336,
      628,  683,  765, 2012,  308, 2012, 2012,  719,    0,  709,
      696, 2012, 2012,   71, 2012,   54,   64,  294,  725,   38,
        0,   52,   56,   58,   69,   75,  317,  328,   56,   73,
      324,   78,  275,  213,  778, 2012,  104,  377,  243,  463,
     2012,  386, 2012,  699,  603,  581,  100,    0,  205,  253,
      826,  198,  232,  574,  879, 2012,  414, 2012,  441, 2012,
      457, 2012,  472, 2012, 2012,  468,  473, 2012, 2012,  277,
      352,  463,  499,  293,  500,  357,  359, 2012, 2012,  474,

     2012, 2012, 2012, 2012,  478, 2012,  532, 2012, 2012, 2012,
     2012,  301,  482, 2012,  584, 2012,  498,  484,  107,  519,
      534, 2012,  599,  365,  640,    0, 2012,  619, 2012,  544,
     2012,  620, 2012, 2012,  577,  621,  591,  441,  439, 2012,
      420,  401,  397,  366,  650,    0,  353,  367,  613,  389,
     2012,  534,  605,  667,  503,    0,  509,  536,  552,  643,
      648,  680,  654,  657,  674,  682,  713,  685,  678,  679,
      692,  692,  723,  716,    0,  750,  729,  729,    0,  707,
     2012,  352,  762,  711,  307, 2012,  791,  766, 2012, 2012,
      822,  427,    0,  752,  792,  757,    0,  749,  778,    0,

      855,  859,  861,  780,  813,  834,  831,  927,  844,  837,
      852,  862,  853,  846,  889,  917,  262, 1007, 1008,  250,
      326, 1012, 2012,  377,  772,  306,  298,  294,  290,  487,
     2012,  513, 1016,  909,  537, 1008,    0,  237, 2012, 2012,
        0,  978,  978,  986,  994,  996,  990,  992,  988, 1010,
     1003,  997, 1009, 1016, 1020, 1016, 1011, 1024, 1009, 1016,
     1025, 1030, 1031,    0, 1014, 1013, 1029, 1018, 1026, 1047,
        0,    0, 1041, 1048, 1047, 2012,  235,  251, 1070, 1071,
      828, 2012, 2012, 1055, 1068,    0, 1054, 1067, 1056, 1058,
     1067,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0, 1068, 1070, 1081, 1078, 1072, 1137,    0, 1099, 1073,
        0,    0, 1113,    0, 1120, 1085, 1142, 1071, 1137, 1147,
     1136, 1122,    0,    0,    0,    0,    0, 1120, 1124, 1142,
     1136, 1133, 1138, 1148, 1152,    0,  580, 2012,  596,  647,
      600, 2012,  606,  218,  929, 1145,    0, 1147, 1161,    0,
     1194, 1159, 1157, 1167, 1169, 1180, 1192, 1174, 1184, 1179,
     1180, 1194, 1202, 1189,    0, 1186, 1193,    0, 1192, 1191,
     1207, 1210, 1210, 1209, 1208, 1217, 1222, 1239,    0, 1208,
        0, 1202, 2012, 1204, 2012,    0, 1203, 1237, 1228, 1245,
     1243, 1237, 1257, 1241, 1260, 1305,  853,    0,    0,    0,

        0,    0,    0,    0, 1262, 1260, 1259, 1261, 1274, 1322,
     1291,  253, 1300, 1304, 1319, 1309, 1307, 1320, 1310, 1320,
     1329, 1330, 1330,    0, 2012, 1321, 1330, 1318, 2012, 1327,
     1336, 1323,    0, 1366, 1368, 1397, 1401, 2012,  368, 1364,
      237, 1367, 1404, 1373, 1372, 1363, 1379, 1385, 1379,    0,
     1367,    0, 1392, 1396, 1378,    0, 1393, 1387, 1399, 1378,
     1390, 1430,    0, 1399, 1388,  533, 1394, 1399, 1425,  212,
     1409, 2012, 1425,    0, 1421, 1431, 1426, 1431, 1435, 1430,
        0, 1437,    0, 1447, 1452,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0, 1449, 1447,    0, 1446, 1438,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0, 1444, 1451, 1449, 1451,
     1450,    0, 1445, 1456, 1453, 1452, 1449, 1463, 1471, 1471,
     1490, 1481, 1499,    0, 2012, 1483, 2012, 2012, 1485, 2012,
     1533, 2012, 1371, 2012,    0, 1526, 1537, 1495, 1494, 1492,
     1538, 1499, 1513, 1496, 1507,    0, 1506, 1518,    0, 1523,
     1520, 1526,    0,    0, 1556, 1521,    0, 1521, 1564, 1528,
     1532, 1532, 2012, 1523, 1548, 1548, 1564,    0,    0, 1552,
     1566, 1550,    0, 1553, 1562,    0, 1574, 1560,    0, 1561,
     1568, 1563, 1584, 1586, 1573, 1584, 1576,    0,    0, 1589,

     1579, 1580, 1590, 1583, 1598, 1602, 2012, 2012, 2012, 1594,
     1599,  716,  761, 1593, 1640, 1621, 1643, 1612,    0, 1619,
        0, 1624, 1630, 1630,    0, 1636,    0, 1622, 1636,    0,
     1637,    0, 1639,  210,    0, 2012, 1625, 1628,    0,    0,
     1633,    0,    0, 1635,    0,    0, 1629, 1632, 1634, 1636,
     1656,    0, 1656,    0,    0,    0, 1650,    0,    0,    0,
     1644, 1657, 1666, 1654, 1648, 1664, 1662, 1665, 1665,    0,
     1711, 1689, 1690, 1674, 1675, 2012, 1696, 1694, 1692,    0,
     1686,    0, 1699,    0, 1697,    0,    0, 1700, 1707, 1686,
     1701, 1695, 1690,    0, 1713, 1714, 1740, 1720, 1721, 1708,

     1709, 1731,    0,    0,    0,    0,    0,    0, 2012, 1721,
     1723, 1721, 1770,    0, 1767, 1736, 1758, 1735, 1742, 1775,
     2012, 1747, 1760, 1787, 2012, 1788, 1759, 1793, 1754, 1752,
     1749, 1760, 1803, 1806, 1776, 1779, 1776, 1781, 1782, 1778,
     1793, 1789, 1797, 1792, 1813, 1800, 1801, 2012, 1814,    0,
     1817, 1817, 1809, 1804, 1809, 1814, 1812, 1830, 2012, 1830,
        0, 1823, 1818,    0, 1821,    0,    0, 2012,    0, 2012,
     2012, 2012, 1895, 1900, 1905, 1910, 1915, 1920, 1925, 1930,
     1935, 1938, 1943, 1948, 1951, 1954, 1957, 1962, 1967, 1972,
     1977,  119,  109, 1980, 1985, 1990, 1995, 1998, 2001, 2006

    } ;

static const flex_int16_t yy_def[801] =
    {   0,
      772,    1,  772,    3,  773,  773,  774,  774,  775,  775,
      776,  776,  777,  777,  778,  778,  775,   17,  779,  779,
      780,  780,  772,  772,  772,  772,  772,  781,  782,  783,
      784,  772,  772,  772,  772,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  772,  772,  772,  786,  785,
      772,  772,  772,  781,  783,  784,  772,  787,  787,  787,
      787,  787,  787,  787,  787,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,

      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  788,  772,  789,  790,  791,  772,
      772,  772,  772,  772,  772,  792,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  781,  781,  772,
      783,  783,  784,  784,  772,  785,  785,  785,  785,  785,
      772,  785,  785,   39,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  793,  785,  785,  785,   55,  772,
      772,  772,  772,  772,  794,  772,  794,  772,  772,  772,
      772,  772,  787,  787,   71,  787,  787,  787,  787,   75,

      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  795,
      788,  788,  772,  788,  788,  789,  789,  790,  790,  791,
      772,  791,  772,  772,  796,  772,  792,  797,  772,  772,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      793,  785,  785,  785,  785,  772,  797,  794,  794,  794,
      772,  772,  772,  787,  787,  787,  787,  772,  772,  772,
      772,  798,  798,  798,  798,  798,  798,  798,  798,  798,

      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  772,  772,  772,
      772,  772,  772,  772,  772,  799,  795,  772,  795,  800,
      796,  772,  796,  797,  797,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  794,  794,  787,  787,
      787,  772,  772,  772,  772,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,

      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  772,  772,  772,  772,  772,  772,
      772,  772,  799,  800,  800,  800,  797,  772,  797,  785,
      785,  785,  772,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  794,  794,
      787,  772,  772,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,

      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  772,  772,  772,  772,  772,  772,
      800,  772,  800,  772,  785,  772,  785,  772,  772,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  785,  772,  785,  785,  785,  772,  785,
      785,  794,  772,  787,  772,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,

      798,  798,  798,  798,  798,  798,  772,  772,  772,  772,
      772,  772,  785,  772,  772,  785,  772,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  772,  785,  785,
      772,  785,  785,  794,  787,  772,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      772,  772,  772,  772,  785,  785,  785,  785,  785,  785,
      785,  772,  785,  772,  785,  772,  798,  798,  798,  798,
      798,  798,  798,  798,  798,  798,  798,  772,  772,  772,
      772,  785,  785,  785,  785,  785,  772,  785,  772,  785,

      772,  785,  798,  798,  798,  798,  798,  798,  772,  772,
      772,  772,  785,  785,  785,  785,  772,  785,  772,  785,
      772,  785,  772,  772,  772,  772,  785,  772,  785,  785,
      772,  785,  772,  772,  785,  785,  772,  772,  785,  772,
      785,  785,  772,  785,  772,  785,  785,  772,  772,  785,
      772,  785,  785,  772,  785,  772,  785,  785,  772,  772,
      785,  785,  772,  785,  772,  785,  785,  772,  785,  772,
      772,    0,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772

    } ;

static const flex_int16_t yy_nxt[2094] =
    {   0,
       24,   25,   26,   27,   25,   28,   29,   30,   31,   32,
       33,   24,   24,   34,   34,   34,   34,   34,   34,   34,
       34,   24,   24,   24,   35,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   41,   45,   46,   47,   48,   49,
       41,   41,   50,   51,   52,   53,   54,   41,   55,   41,
       41,   56,   57,   24,   24,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   41,   45,   46,   47,   48,   49,
       41,   41,   50,   51,   52,   53,   54,   41,   55,   41,
       41,   58,  157,   59,  145,  145,  145,  145,  145,  145,
      145,  145,  147,  149,  158,  159,  160,  150,  161,  148,

      162,  169,  170,  174,   60,  180,  181,  182,  180,  231,
      232,  271,  157,  145,  145,  145,  145,  145,  145,  145,
      145,  237,  147,  149,  158,  159,  160,  150,  161,  148,
      162,  169,  170,  174,   60,   61,   62,   26,   63,   62,
       64,   61,   65,   66,   61,   61,   61,   61,   67,   67,
       67,   67,   67,   67,   67,   67,   61,   61,   61,   61,
       68,   69,   70,   71,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   72,   73,   68,   68,   68,   68,   68,
       74,   68,   68,   75,   68,   68,   76,   77,   61,   61,
       68,   69,   70,   71,   68,   68,   68,   68,   68,   68,

       68,   68,   68,   72,   73,   68,   68,   68,   68,   68,
       74,   68,   68,   75,   68,   68,   79,   26,   80,   79,
       79,   26,   80,   79,   83,   26,   84,   83,   83,   26,
       84,   83,   85,  676,  194,  573,   85,  100,   26,  101,
      100,  546,  177,  198,  102,  103,  178,  104,  100,   26,
      101,  100,  338,  339,  151,  102,  103,  151,  104,  115,
       26,  116,  115,  117,  194,  118,  186,   81,  522,  119,
      345,   81,  177,  198,  186,   86,  178,  199,  187,   86,
       87,   26,   63,   87,   88,  175,   89,  345,  105,  345,
      115,   26,  116,  115,  117,  151,  118,  229,  151,  105,

      119,  229,  220,  227,   90,  220,   91,  199,  187,  136,
      120,  227,  136,  204,   92,   93,  336,   94,  176,  152,
      212,   95,   96,  128,   26,  129,  128,   97,  223,  224,
      186,   77,   98,  153,   90,  137,   91,  128,   26,  129,
      128,  120,  163,  204,   92,   93,  164,   94,  176,  152,
      212,   95,   96,  166,  276,  165,  171,   97,   87,   26,
       63,   87,   88,  153,   89,  137,  235,  167,  172,  235,
      544,  173,  163,  168,  130,  144,  164,  205,  136,  223,
      224,  183,   90,  166,   91,  165,  171,  191,  130,  216,
      191,  206,   92,   93,  217,   94,  207,  167,  172,   95,

       96,  173,  241,  168,  184,   97,  144,  205,  142,   77,
       98,  242,   90,  192,   91,  180,  181,  182,  180,  216,
      345,  206,   92,   93,  217,   94,  207,  142,  238,   95,
       96,  238,  241,  245,  184,   97,  107,   26,  108,  107,
      109,  242,  201,  192,  139,  201,  139,  110,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  180,  181,
      182,  180,  112,  245,  188,  189,  190,  188,  192,  180,
      181,  182,  180,  202,  203,  218,  202,  203,  218,  180,
      181,  182,  180,  180,  181,  182,  180,  113,  152,  231,
      232,  229,  112,  107,   26,  108,  107,  109,  192,  192,

      192,  192,  153,  227,  110,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  231,  232,  208,  152,  112,
      180,  181,  182,  180,  209,  213,  210,  214,  250,  192,
      192,  192,  153,  219,  569,  233,  219,  569,  233,  342,
      343,  251,  211,  215,  113,  180,  181,  182,  180,  112,
      121,   26,   63,  121,  209,  213,  210,  214,  250,  192,
      122,  192,  123,  123,  123,  123,  123,  123,  123,  123,
      246,  251,  211,  215,  247,  252,  124,  125,  180,  181,
      182,  180,  338,  339,  175,  222,  223,  224,  222,  192,
      144,  192,  238,  239,  240,  238,  253,  126,  338,  339,

      246,   77,  342,  343,  247,  252,  124,  125,  342,  343,
      142,  225,  234,  234,  234,  234,  234,  234,  234,  234,
      201,  201,  136,  201,  201,  136,  253,  126,  131,  132,
       26,  133,  132,  131,  131,  131,  131,  131,  131,  131,
      131,  225,  243,  248,  244,  249,  192,  192,  137,  223,
      435,  131,  131,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  145,  145,  145,  145,  145,  145,  145,
      145,  254,  243,  248,  244,  249,  192,  192,  137,  131,
      135,  131,  131,  131,  132,   26,  133,  132,  131,  131,
      131,  131,  131,  131,  131,  131,  146,  255,  258,  436,

      259,  254,  146,  260,  139,  144,  131,  131,  180,  181,
      182,  180,  277,  239,  240,  277,  142,  612,  256,  261,
      612,  264,  265,  266,  139,  267,  146,  255,  258,  257,
      259,  268,  146,  260,  131,  135,  131,  131,  154,  154,
      154,  154,  154,  154,  154,  154,  154,  154,  256,  261,
      262,  264,  265,  266,  155,  267,  269,  263,  270,  257,
      156,  268,  612,  136,  772,  612,  183,  281,  282,  283,
      281,  274,  275,  340,  223,  224,  340,  772,  772,  272,
      262,  284,  285,  273,  155,  286,  269,  263,  270,  184,
      156,  179,  179,  179,  179,  179,  179,  179,  179,  179,

      179,  274,  275,  179,  179,  179,  179,  179,  179,  272,
      772,  284,  285,  273,  186,  286,  772,  772,  772,  184,
      279,  193,  287,  191,  288,  772,  191,  193,  280,  281,
      282,  283,  281,  179,  179,  179,  179,  179,  179,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  192,
      279,  193,  287,  289,  288,  196,  201,  193,  280,  201,
      202,  197,  203,  202,  772,  203,  497,  498,  499,  500,
      501,  772,  290,  291,  772,  772,  772,  772,  772,  192,
      328,  329,  192,  289,  330,  196,  192,  331,  192,  332,
      333,  197,  200,  200,  200,  200,  200,  200,  200,  200,

      200,  200,  290,  291,  200,  200,  200,  200,  200,  200,
      328,  329,  192,  772,  330,  772,  192,  331,  192,  332,
      333,  334,  234,  234,  234,  234,  234,  234,  234,  234,
      437,  438,  439,  437,  200,  200,  200,  200,  200,  200,
      292,  293,  294,  295,  296,  297,  298,  299,  300,  301,
      335,  334,  302,  303,  304,  305,  306,  307,  308,  309,
      310,  311,  312,  313,  314,  315,  316,  317,  318,  319,
      320,  321,  322,  323,  324,  325,  326,  327,  772,  772,
      335,  345,  302,  303,  304,  305,  306,  307,  308,  309,
      310,  311,  312,  313,  314,  315,  316,  317,  318,  319,

      320,  321,  322,  323,  324,  325,  326,  327,  218,  219,
      346,  218,  219,  222,  223,  224,  222,  233,  347,  348,
      233,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  349,  350,  351,  192,  192,  352,  353,  354,  225,
      346,  355,  356,  192,  357,  358,  359,  360,  347,  348,
      361,  362,  363,  364,  365,  366,  367,  368,  369,  370,
      371,  349,  350,  351,  192,  192,  352,  353,  354,  225,
      372,  355,  356,  192,  357,  358,  359,  360,  373,  374,
      361,  362,  363,  364,  365,  366,  367,  368,  369,  370,
      371,  375,  376,  186,  186,  379,  380,  381,  382,  383,

      372,  378,  384,  385,  387,  388,  389,  391,  373,  374,
      393,  407,  772,  394,  412,  395,  416,  392,  772,  377,
      390,  375,  376,  772,  772,  379,  380,  381,  382,  383,
      772,  378,  384,  385,  387,  388,  389,  391,  405,  408,
      393,  407,  409,  394,  412,  395,  416,  392,  406,  377,
      390,  396,  397,  398,  399,  400,  401,  402,  403,  404,
      410,  423,  424,  417,  425,  411,  426,  413,  405,  408,
      418,  414,  409,  415,  419,  427,  428,  429,  406,  420,
      430,  431,  432,  421,  440,  441,  442,  422,  446,  772,
      410,  423,  424,  417,  425,  411,  426,  413,  443,  447,

      418,  414,  448,  415,  419,  427,  428,  429,  449,  420,
      430,  431,  432,  421,  440,  441,  442,  422,  446,  444,
      450,  451,  452,  453,  454,  455,  456,  457,  458,  447,
      459,  460,  448,  445,  461,  462,  463,  464,  449,  465,
      466,  467,  468,  471,  472,  186,  473,  474,  772,  444,
      450,  451,  452,  453,  454,  455,  456,  457,  458,  469,
      459,  460,  186,  445,  461,  462,  463,  464,  477,  465,
      466,  467,  468,  471,  472,  470,  473,  474,  475,  481,
      476,  478,  479,  480,  482,  483,  485,  486,  772,  469,
      772,  772,  772,  772,  772,  772,  772,  772,  477,  502,

      503,  484,  504,  505,  506,  470,  772,  772,  475,  481,
      476,  478,  479,  480,  482,  483,  485,  486,  487,  488,
      489,  490,  491,  492,  493,  494,  495,  496,  521,  502,
      503,  484,  504,  505,  506,  507,  508,  509,  510,  511,
      512,  513,  514,  515,  516,  523,  524,  525,  527,  528,
      517,  529,  530,  531,  532,  533,  534,  535,  521,  518,
      536,  537,  519,  538,  526,  520,  539,  540,  223,  435,
      223,  435,  772,  609,  435,  523,  524,  525,  527,  528,
      517,  529,  530,  531,  532,  533,  534,  535,  772,  518,
      536,  537,  519,  538,  526,  520,  539,  540,  541,  542,

      543,  541,  437,  438,  439,  437,  545,  547,  443,  550,
      551,  552,  553,  772,  554,  555,  556,  557,  436,  772,
      436,  558,  559,  436,  560,  561,  562,  563,  564,  548,
      772,  567,  568,  570,  565,  571,  545,  547,  574,  550,
      551,  552,  553,  549,  554,  555,  556,  557,  186,  436,
      572,  558,  559,  345,  560,  561,  562,  563,  564,  548,
      566,  567,  568,  570,  575,  571,  576,  577,  574,  579,
      580,  578,  581,  549,  582,  583,  584,  585,  586,  587,
      572,  588,  589,  590,  591,  592,  595,  593,  596,  597,
      566,  598,  599,  600,  575,  594,  576,  577,  601,  579,

      580,  578,  581,  602,  582,  583,  584,  585,  586,  587,
      603,  588,  589,  590,  591,  592,  595,  593,  596,  597,
      604,  598,  599,  600,  605,  594,  606,  607,  601,  608,
      546,  614,  615,  602,  541,  542,  543,  541,  612,  616,
      603,  612,  617,  619,  620,  621,  622,  772,  623,  624,
      604,  610,  625,  626,  605,  186,  606,  607,  627,  608,
      565,  614,  615,  629,  630,  569,  632,  633,  569,  616,
      634,  611,  635,  619,  620,  621,  622,  618,  623,  624,
      613,  610,  625,  626,  636,  436,  628,  637,  627,  638,
      639,  640,  641,  629,  630,  642,  632,  633,  643,  631,

      634,  611,  635,  644,  645,  646,  647,  618,  648,  649,
      613,  650,  651,  652,  636,  653,  628,  637,  654,  638,
      639,  640,  641,  655,  656,  642,  657,  658,  643,  631,
      659,  660,  661,  644,  645,  646,  647,  662,  648,  649,
      663,  650,  651,  652,  617,  653,  665,  617,  654,  772,
      666,  667,  772,  655,  656,  668,  657,  658,  669,  670,
      659,  660,  661,  671,  672,  673,  674,  662,  675,  677,
      663,  678,  679,  680,  681,  682,  665,  683,  684,  664,
      666,  667,  664,  685,  686,  668,  687,  688,  669,  670,
      689,  690,  691,  671,  672,  673,  674,  692,  675,  677,

      693,  678,  679,  680,  681,  682,  694,  683,  684,  664,
      695,  696,  664,  685,  686,  697,  687,  688,  699,  700,
      689,  690,  691,  701,  702,  703,  704,  692,  705,  706,
      693,  707,  708,  709,  710,  711,  694,  712,  713,  714,
      695,  696,  715,  716,  697,  718,  772,  698,  699,  700,
      719,  720,  721,  701,  702,  703,  704,  722,  705,  706,
      723,  707,  708,  709,  710,  711,  724,  712,  713,  714,
      725,  728,  715,  716,  726,  718,  717,  698,  730,  734,
      719,  720,  721,  731,  732,  733,  736,  722,  737,  739,
      723,  726,  726,  741,  729,  742,  724,  728,  743,  744,

      725,  746,  735,  772,  747,  748,  717,  734,  730,  727,
      734,  749,  750,  731,  732,  733,  736,  751,  737,  739,
      740,  752,  753,  741,  729,  742,  738,  738,  743,  744,
      745,  746,  735,  745,  747,  748,  754,  755,  756,  727,
      757,  749,  750,  758,  759,  760,  761,  751,  762,  763,
      740,  752,  753,  764,  765,  766,  738,  738,  767,  768,
      745,  769,  770,  745,  771,  772,  754,  755,  756,  772,
      757,  772,  772,  758,  759,  760,  761,  772,  762,  763,
      772,  772,  772,  764,  765,  766,  772,  772,  767,  768,
      772,  769,  770,  772,  771,   78,   78,   78,   78,   78,

       82,   82,   82,   82,   82,   61,   61,   61,   61,   61,
       99,   99,   99,   99,   99,  106,  106,  106,  106,  106,
      114,  114,  114,  114,  114,  127,  127,  127,  127,  127,
      134,  134,  134,  134,  134,  138,  772,  138,  138,  138,
      140,  772,  140,  141,  772,  141,  141,  141,  143,  772,
      143,  143,  143,  146,  772,  146,  185,  185,  185,  193,
      772,  193,  221,  221,  221,  221,  221,  226,  772,  226,
      226,  226,  228,  772,  228,  228,  228,  230,  230,  230,
      230,  230,  278,  278,  278,  337,  337,  337,  337,  337,
      341,  341,  341,  341,  341,  344,  772,  344,  344,  344,

      386,  772,  386,  433,  772,  433,  434,  434,  434,  434,
      434,   23,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772

    } ;

static const flex_int16_t yy_chk[2094] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,   40,    2,   34,   34,   34,   34,   34,   34,
       34,   34,   36,   37,   42,   43,   44,   37,   45,   36,

       46,   49,   50,   52,    2,   57,   57,   57,   57,  119,
      119,  793,   40,   67,   67,   67,   67,   67,   67,   67,
       67,  792,   36,   37,   42,   43,   44,   37,   45,   36,
       46,   49,   50,   52,    2,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    5,    5,    5,    5,
        6,    6,    6,    6,    7,    7,    7,    7,    8,    8,
        8,    8,    7,  634,   69,  470,    8,   11,   11,   11,
       11,  441,   54,   72,   11,   11,   54,   11,   12,   12,
       12,   12,  220,  220,   70,   12,   12,   70,   12,   15,
       15,   15,   15,   15,   69,   15,   59,    5,  412,   15,
      344,    6,   54,   72,  278,    7,   54,   73,   59,    8,
        9,    9,    9,    9,    9,   53,    9,  277,   11,  238,
       16,   16,   16,   16,   16,   38,   16,  229,   38,   12,

       16,  228,  112,  227,    9,  112,    9,   73,   59,   25,
       15,  226,   25,   90,    9,    9,  217,    9,   53,   38,
       94,    9,    9,   19,   19,   19,   19,    9,  221,  221,
      185,    9,    9,   38,    9,   25,    9,   20,   20,   20,
       20,   16,   47,   90,    9,    9,   47,    9,   53,   38,
       94,    9,    9,   48,  182,   47,   51,    9,   10,   10,
       10,   10,   10,   38,   10,   25,  124,   48,   51,  124,
      439,   51,   47,   48,   19,  144,   47,   91,   58,  224,
      224,   58,   10,   48,   10,   47,   51,   62,   20,   96,
       62,   91,   10,   10,   97,   10,   91,   48,   51,   10,

       10,   51,  147,   48,   58,   10,  143,   91,  142,   10,
       10,  148,   10,   62,   10,   77,   77,   77,   77,   96,
      439,   91,   10,   10,   97,   10,   91,  141,  192,   10,
       10,  192,  147,  150,   58,   10,   13,   13,   13,   13,
       13,  148,   79,   62,  139,   79,  138,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   81,   81,
       81,   81,   13,  150,   60,   60,   60,   60,   79,   86,
       86,   86,   86,   83,   87,  100,   83,   87,  100,  105,
      105,  105,  105,  113,  113,  113,  113,   13,   60,  230,
      230,  118,   13,   14,   14,   14,   14,   14,   79,   83,

       87,  100,   60,  117,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,  232,  232,   92,   60,   14,
      120,  120,  120,  120,   93,   95,   93,   95,  155,   83,
       87,  100,   60,  107,  466,  121,  107,  466,  121,  235,
      235,  157,   93,   95,   14,  130,  130,  130,  130,   14,
       17,   17,   17,   17,   93,   95,   93,   95,  155,  107,
       17,  121,   17,   17,   17,   17,   17,   17,   17,   17,
      152,  157,   93,   95,  152,  158,   17,   17,  135,  135,
      135,  135,  337,  337,   74,  115,  115,  115,  115,  107,
       66,  121,  137,  137,  137,  137,  159,   17,  339,  339,

      152,   17,  341,  341,  152,  158,   17,   17,  343,  343,
       65,  115,  123,  123,  123,  123,  123,  123,  123,  123,
      128,  132,  136,  128,  132,  136,  159,   17,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,  115,  149,  153,  149,  153,  128,  132,  136,  340,
      340,   21,   21,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  145,  145,  145,  145,  145,  145,  145,
      145,  160,  149,  153,  149,  153,  128,  132,  136,   21,
       21,   21,   21,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,  154,  161,  163,  340,

      164,  160,  154,  165,   64,   31,   22,   22,  180,  180,
      180,  180,  184,  184,  184,  184,   30,  612,  162,  166,
      612,  168,  169,  170,   28,  171,  154,  161,  163,  162,
      164,  172,  154,  165,   22,   22,   22,   22,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,  162,  166,
      167,  168,  169,  170,   39,  171,  173,  167,  174,  162,
       39,  172,  613,  183,   23,  613,  183,  188,  188,  188,
      188,  177,  178,  225,  225,  225,  225,    0,    0,  176,
      167,  194,  196,  176,   39,  198,  173,  167,  174,  183,
       39,   55,   55,   55,   55,   55,   55,   55,   55,   55,

       55,  177,  178,   55,   55,   55,   55,   55,   55,  176,
        0,  194,  196,  176,  187,  198,    0,    0,    0,  183,
      187,  195,  199,  191,  204,    0,  191,  195,  187,  281,
      281,  281,  281,   55,   55,   55,   55,   55,   55,   71,
       71,   71,   71,   71,   71,   71,   71,   71,   71,  191,
      187,  195,  199,  205,  204,   71,  201,  195,  187,  201,
      202,   71,  203,  202,    0,  203,  397,  397,  397,  397,
      397,    0,  206,  207,    0,    0,    0,    0,    0,  191,
      209,  210,  201,  205,  211,   71,  202,  212,  203,  213,
      214,   71,   75,   75,   75,   75,   75,   75,   75,   75,

       75,   75,  206,  207,   75,   75,   75,   75,   75,   75,
      209,  210,  201,    0,  211,    0,  202,  212,  203,  213,
      214,  215,  234,  234,  234,  234,  234,  234,  234,  234,
      345,  345,  345,  345,   75,   75,   75,   75,   75,   75,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      216,  215,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,    0,    0,
      216,  345,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,

      208,  208,  208,  208,  208,  208,  208,  208,  218,  219,
      242,  218,  219,  222,  222,  222,  222,  233,  243,  244,
      233,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  245,  246,  247,  218,  219,  248,  249,  250,  222,
      242,  251,  252,  233,  253,  254,  255,  256,  243,  244,
      257,  258,  259,  260,  261,  262,  263,  265,  266,  267,
      268,  245,  246,  247,  218,  219,  248,  249,  250,  222,
      269,  251,  252,  233,  253,  254,  255,  256,  270,  273,
      257,  258,  259,  260,  261,  262,  263,  265,  266,  267,
      268,  274,  275,  279,  280,  284,  285,  287,  288,  289,

      269,  280,  290,  291,  302,  303,  304,  305,  270,  273,
      306,  310,    0,  306,  316,  306,  318,  305,    0,  279,
      304,  274,  275,    0,    0,  284,  285,  287,  288,  289,
        0,  280,  290,  291,  302,  303,  304,  305,  309,  313,
      306,  310,  313,  306,  316,  306,  318,  305,  309,  279,
      304,  307,  307,  307,  307,  307,  307,  307,  307,  307,
      315,  321,  322,  319,  328,  315,  329,  317,  309,  313,
      319,  317,  313,  317,  320,  330,  331,  332,  309,  320,
      333,  334,  335,  320,  346,  348,  349,  320,  352,    0,
      315,  321,  322,  319,  328,  315,  329,  317,  351,  353,

      319,  317,  354,  317,  320,  330,  331,  332,  355,  320,
      333,  334,  335,  320,  346,  348,  349,  320,  352,  351,
      356,  357,  358,  359,  360,  361,  362,  363,  364,  353,
      366,  367,  354,  351,  369,  370,  371,  372,  355,  373,
      374,  375,  376,  380,  382,  377,  384,  387,    0,  351,
      356,  357,  358,  359,  360,  361,  362,  363,  364,  377,
      366,  367,  378,  351,  369,  370,  371,  372,  389,  373,
      374,  375,  376,  380,  382,  378,  384,  387,  388,  391,
      388,  390,  390,  390,  392,  393,  394,  395,    0,  377,
        0,    0,    0,    0,    0,    0,    0,    0,  389,  405,

      406,  393,  407,  408,  409,  378,    0,    0,  388,  391,
      388,  390,  390,  390,  392,  393,  394,  395,  396,  396,
      396,  396,  396,  396,  396,  396,  396,  396,  411,  405,
      406,  393,  407,  408,  409,  410,  410,  410,  410,  410,
      410,  410,  410,  410,  410,  413,  414,  415,  416,  417,
      410,  418,  419,  420,  421,  422,  423,  426,  411,  410,
      427,  428,  410,  430,  415,  410,  431,  432,  434,  434,
      435,  435,    0,  543,  543,  413,  414,  415,  416,  417,
      410,  418,  419,  420,  421,  422,  423,  426,    0,  410,
      427,  428,  410,  430,  415,  410,  431,  432,  436,  436,

      436,  436,  437,  437,  437,  437,  440,  442,  443,  444,
      445,  446,  447,    0,  448,  449,  451,  453,  434,    0,
      435,  454,  455,  543,  457,  458,  459,  460,  461,  443,
        0,  464,  465,  467,  462,  468,  440,  442,  471,  444,
      445,  446,  447,  443,  448,  449,  451,  453,  469,  436,
      469,  454,  455,  437,  457,  458,  459,  460,  461,  443,
      462,  464,  465,  467,  473,  468,  475,  476,  471,  477,
      478,  476,  479,  443,  480,  482,  484,  485,  502,  503,
      469,  505,  506,  517,  518,  519,  521,  520,  523,  524,
      462,  525,  526,  527,  473,  520,  475,  476,  528,  477,

      478,  476,  479,  529,  480,  482,  484,  485,  502,  503,
      530,  505,  506,  517,  518,  519,  521,  520,  523,  524,
      531,  525,  526,  527,  532,  520,  533,  536,  528,  539,
      546,  548,  549,  529,  541,  541,  541,  541,  547,  550,
      530,  547,  551,  552,  553,  554,  555,    0,  557,  558,
      531,  546,  560,  561,  532,  572,  533,  536,  562,  539,
      565,  548,  549,  566,  568,  569,  570,  571,  569,  550,
      572,  546,  574,  552,  553,  554,  555,  551,  557,  558,
      547,  546,  560,  561,  575,  541,  565,  576,  562,  577,
      580,  581,  582,  566,  568,  584,  570,  571,  585,  569,

      572,  546,  574,  587,  588,  590,  591,  551,  592,  593,
      547,  594,  595,  596,  575,  597,  565,  576,  600,  577,
      580,  581,  582,  601,  602,  584,  603,  604,  585,  569,
      605,  606,  610,  587,  588,  590,  591,  611,  592,  593,
      614,  594,  595,  596,  615,  597,  616,  617,  600,    0,
      618,  620,    0,  601,  602,  622,  603,  604,  623,  624,
      605,  606,  610,  626,  628,  629,  631,  611,  633,  637,
      614,  638,  641,  644,  647,  648,  616,  649,  650,  615,
      618,  620,  617,  651,  653,  622,  657,  661,  623,  624,
      662,  663,  664,  626,  628,  629,  631,  665,  633,  637,

      666,  638,  641,  644,  647,  648,  667,  649,  650,  615,
      668,  669,  617,  651,  653,  671,  657,  661,  672,  673,
      662,  663,  664,  674,  675,  677,  678,  665,  679,  681,
      666,  683,  685,  688,  689,  690,  667,  691,  692,  693,
      668,  669,  695,  696,  697,  698,    0,  671,  672,  673,
      699,  700,  701,  674,  675,  677,  678,  702,  679,  681,
      710,  683,  685,  688,  689,  690,  711,  691,  692,  693,
      712,  715,  695,  696,  713,  698,  697,  671,  716,  720,
      699,  700,  701,  717,  718,  719,  722,  702,  723,  727,
      710,  724,  726,  729,  715,  730,  711,  728,  731,  732,

      712,  735,  720,    0,  736,  737,  697,  733,  716,  713,
      734,  738,  739,  717,  718,  719,  722,  740,  723,  727,
      728,  741,  742,  729,  715,  730,  724,  726,  731,  732,
      733,  735,  720,  734,  736,  737,  743,  744,  745,  713,
      746,  738,  739,  747,  749,  751,  752,  740,  753,  754,
      728,  741,  742,  755,  756,  757,  724,  726,  758,  760,
      733,  762,  763,  734,  765,    0,  743,  744,  745,    0,
      746,    0,    0,  747,  749,  751,  752,    0,  753,  754,
        0,    0,    0,  755,  756,  757,    0,    0,  758,  760,
        0,  762,  763,    0,  765,  773,  773,  773,  773,  773,

      774,  774,  774,  774,  774,  775,  775,  775,  775,  775,
      776,  776,  776,  776,  776,  777,  777,  777,  777,  777,
      778,  778,  778,  778,  778,  779,  779,  779,  779,  779,
      780,  780,  780,  780,  780,  781,    0,  781,  781,  781,
      782,    0,  782,  783,    0,  783,  783,  783,  784,    0,
      784,  784,  784,  785,    0,  785,  786,  786,  786,  787,
        0,  787,  788,  788,  788,  788,  788,  789,    0,  789,
      789,  789,  790,    0,  790,  790,  790,  791,  791,  791,
      791,  791,  794,  794,  794,  795,  795,  795,  795,  795,
      796,  796,  796,  796,  796,  797,    0,  797,  797,  797,

      798,    0,  798,  799,    0,  799,  800,  800,  800,  800,
      800,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772

    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../../kmflcomp/src/lex.l"
#line 2 "../../kmflcomp/src/lex.l"
/* lex.l: Lex parser for Keyman keyboard source files for kmflcomp compiler */

/* Derived from version written by David Gardner for k_tty */

#include <stdio.h>
#include <stdlib.h>

#include "compiler.h"
#include "yacc.h"

void yyerror(char *);

#if defined(FLEX_SCANNER) && ! defined(INITIAL)
int caller=0,caller0=0;
#else
int caller= INITIAL,caller0=INITIAL;
#endif

char qchar;
extern int lineno;
extern int errcount;
int done=0;

void yycleanup(void)
{
    yy_delete_buffer(YY_CURRENT_BUFFER);
}

int yyterminate(void)
{
	yyerror("END\n");
	fflush(stderr); 
	return YY_NULL;
}

#line 1204 "lex.c"

#line 1206 "lex.c"

#define INITIAL 0
#define STOR 1
#define QUOTE 2
#define PARENS 3
#define KEYNAME 4
#define PLIST 5
#define KBDVER 6
#define BITMAP 7
#define LNGCODE 8
#define SKIP 9
#define NAME 10

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 53 "../../kmflcomp/src/lex.l"


#line 1439 "lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 773 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2012 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 55 "../../kmflcomp/src/lex.l"
{lineno++;caller=INITIAL;BEGIN(INITIAL);return(TOK_NL);}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 56 "../../kmflcomp/src/lex.l"
{/* just ignore carriage returns */};
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(STOR):
case YY_STATE_EOF(QUOTE):
case YY_STATE_EOF(PARENS):
case YY_STATE_EOF(KEYNAME):
case YY_STATE_EOF(PLIST):
case YY_STATE_EOF(KBDVER):
case YY_STATE_EOF(BITMAP):
case YY_STATE_EOF(LNGCODE):
case YY_STATE_EOF(SKIP):
case YY_STATE_EOF(NAME):
#line 58 "../../kmflcomp/src/lex.l"
{
				if(done){yyterminate();}
				else    {done=1;lineno++;caller=INITIAL;BEGIN(INITIAL);return(TOK_NL);}
			}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 63 "../../kmflcomp/src/lex.l"
{return TOK_NAME;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 64 "../../kmflcomp/src/lex.l"
{BEGIN(BITMAP);return TOK_BITMAP;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 65 "../../kmflcomp/src/lex.l"
{caller=STOR;BEGIN(STOR);return TOK_HOTKEY;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 66 "../../kmflcomp/src/lex.l"
{BEGIN(KBDVER);return TOK_VERSION;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 67 "../../kmflcomp/src/lex.l"
{BEGIN(LNGCODE);return TOK_LANGUAGE;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 68 "../../kmflcomp/src/lex.l"
{return TOK_LAYOUT;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 69 "../../kmflcomp/src/lex.l"
{return TOK_CAPSOFF;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 70 "../../kmflcomp/src/lex.l"
{return TOK_CAPSON;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 71 "../../kmflcomp/src/lex.l"
{return TOK_CAPSFREE;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 72 "../../kmflcomp/src/lex.l"
{return TOK_COPYRIGHT;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 73 "../../kmflcomp/src/lex.l"
{return TOK_MESSAGE;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 74 "../../kmflcomp/src/lex.l"
{return TOK_MNEMONIC;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 75 "../../kmflcomp/src/lex.l"
{return TOK_ETHNOLOGUE;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 76 "../../kmflcomp/src/lex.l"
{return TOK_AUTHOR;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 77 "../../kmflcomp/src/lex.l"
{return TOK_TARGETS;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 78 "../../kmflcomp/src/lex.l"
{return TOK_VISUALKEYBOARD;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 79 "../../kmflcomp/src/lex.l"
{BEGIN(KBDVER);return TOK_KEYBOARDVERSION;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 80 "../../kmflcomp/src/lex.l"
{return TOK_ANSI;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 81 "../../kmflcomp/src/lex.l"
{return TOK_UNICODE;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 82 "../../kmflcomp/src/lex.l"
{return TOK_ANSI;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 83 "../../kmflcomp/src/lex.l"
{caller=STOR;BEGIN(STOR);return TOK_STORE;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 84 "../../kmflcomp/src/lex.l"
{return TOK_OUTS;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 85 "../../kmflcomp/src/lex.l"
{return TOK_GROUP;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 86 "../../kmflcomp/src/lex.l"
{return TOK_USINGKEYS;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 87 "../../kmflcomp/src/lex.l"
{return TOK_USE;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 88 "../../kmflcomp/src/lex.l"
{return TOK_CONTEXT;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 89 "../../kmflcomp/src/lex.l"
{return TOK_ANY;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 90 "../../kmflcomp/src/lex.l"
{return TOK_NOTANY;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 91 "../../kmflcomp/src/lex.l"
{return TOK_BEEP;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 92 "../../kmflcomp/src/lex.l"
{BEGIN(PLIST);return TOK_INDEX;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 93 "../../kmflcomp/src/lex.l"
{return TOK_NOMATCH;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 94 "../../kmflcomp/src/lex.l"
{return TOK_MATCH;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 95 "../../kmflcomp/src/lex.l"
{return TOK_NUL;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 96 "../../kmflcomp/src/lex.l"
{return TOK_DEADKEY;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 97 "../../kmflcomp/src/lex.l"
{return TOK_DEADKEY;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 98 "../../kmflcomp/src/lex.l"
{return TOK_RTN;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 99 "../../kmflcomp/src/lex.l"
{return TOK_CALL;  /* not implemented */}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 100 "../../kmflcomp/src/lex.l"
{return TOK_SWITCH;/*  (obsolete) */}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 101 "../../kmflcomp/src/lex.l"
{return TOK_GT;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 102 "../../kmflcomp/src/lex.l"
{return TOK_PLUS;}
	YY_BREAK
case 43:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 103 "../../kmflcomp/src/lex.l"
{BEGIN(NAME);return TOK_DOLLAR;}
	YY_BREAK

case 44:
YY_RULE_SETUP
#line 106 "../../kmflcomp/src/lex.l"
{/* ignore spaces */} 
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 107 "../../kmflcomp/src/lex.l"
{BEGIN(SKIP);}
	YY_BREAK
case 46:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 108 "../../kmflcomp/src/lex.l"
{BEGIN(PARENS);return(TOK_BRKT);}
	YY_BREAK
case 47:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 109 "../../kmflcomp/src/lex.l"
{qchar='\'';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 48:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 110 "../../kmflcomp/src/lex.l"
{qchar='"';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 111 "../../kmflcomp/src/lex.l"
{yylval.number=strtol(yytext,NULL,8);return(TOK_NUMBER);}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 112 "../../kmflcomp/src/lex.l"
{yylval.number=atoi(yytext+1);return(TOK_NUMBER);}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 113 "../../kmflcomp/src/lex.l"
{yylval.number=strtol(yytext+1,NULL,16);return(TOK_NUMBER);}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 114 "../../kmflcomp/src/lex.l"
{yylval.number=strtol(yytext+2,NULL,16);return(TOK_NUMBER);}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 115 "../../kmflcomp/src/lex.l"
{BEGIN(KEYNAME);return(TOK_SB);}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 116 "../../kmflcomp/src/lex.l"
{return(TOK_BEEP);}
	YY_BREAK


case 55:
YY_RULE_SETUP
#line 120 "../../kmflcomp/src/lex.l"
{return(TOK_DEADKEY);}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 121 "../../kmflcomp/src/lex.l"
{return(TOK_DEADKEY);}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 122 "../../kmflcomp/src/lex.l"
{return(TOK_OUTS);}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 123 "../../kmflcomp/src/lex.l"
{return(TOK_NUL);}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 124 "../../kmflcomp/src/lex.l"
{return(TOK_ERROR);}
	YY_BREAK


case 60:
YY_RULE_SETUP
#line 128 "../../kmflcomp/src/lex.l"
{/* ignore spaces */}
	YY_BREAK
case 61:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 129 "../../kmflcomp/src/lex.l"
{/* ignore comments */}
	YY_BREAK
case 62:
/* rule 62 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 130 "../../kmflcomp/src/lex.l"
{/* before either EOL */}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 131 "../../kmflcomp/src/lex.l"
{return TOK_QM;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 132 "../../kmflcomp/src/lex.l"
{yylval.number=*yytext;return TOK_CHAR;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 133 "../../kmflcomp/src/lex.l"
{yylval.number=*yytext;return TOK_CHAR;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 134 "../../kmflcomp/src/lex.l"
{BEGIN(SKIP);}
	YY_BREAK


case 67:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 138 "../../kmflcomp/src/lex.l"
{/* ignore anything after a space */}
	YY_BREAK
case 68:
/* rule 68 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 139 "../../kmflcomp/src/lex.l"
{/* including comments */}
	YY_BREAK
case 69:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 140 "../../kmflcomp/src/lex.l"
{qchar='\'';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 70:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 141 "../../kmflcomp/src/lex.l"
{qchar='"';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 142 "../../kmflcomp/src/lex.l"
{yylval.number=*yytext;return TOK_CHAR;}
	YY_BREAK
case 72:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 143 "../../kmflcomp/src/lex.l"
{/* also ignore anything after a comma */}
	YY_BREAK
case 73:
/* rule 73 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 144 "../../kmflcomp/src/lex.l"
{/* before either EOL */}
	YY_BREAK


case 74:
YY_RULE_SETUP
#line 148 "../../kmflcomp/src/lex.l"
{/* ignore spaces */}
	YY_BREAK
case 75:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 149 "../../kmflcomp/src/lex.l"
{/* ignore comments */}
	YY_BREAK
case 76:
/* rule 76 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 150 "../../kmflcomp/src/lex.l"
{/* before either EOL */}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 151 "../../kmflcomp/src/lex.l"
{yylval.number=strtoul(yytext,NULL,8);return(TOK_NUMBER);}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 152 "../../kmflcomp/src/lex.l"
{yylval.number=strtoul(yytext+1,NULL,10);return(TOK_NUMBER);}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 153 "../../kmflcomp/src/lex.l"
{yylval.number=strtoul(yytext+1,NULL,16);return(TOK_NUMBER);}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 154 "../../kmflcomp/src/lex.l"
{/* ignore comma separator */}
	YY_BREAK


case 81:
YY_RULE_SETUP
#line 158 "../../kmflcomp/src/lex.l"
{if (*yytext==qchar) 
					{BEGIN(caller);return(TOK_QM);} 
				else 
					{yylval.number=*yytext;return(TOK_CHAR);}
				}
	YY_BREAK


case 82:
YY_RULE_SETUP
#line 166 "../../kmflcomp/src/lex.l"

	YY_BREAK
case 83:
YY_RULE_SETUP
#line 167 "../../kmflcomp/src/lex.l"
{BEGIN(caller);return(TOK_BRKT);} 
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 168 "../../kmflcomp/src/lex.l"
{yylval.number=*yytext;return(TOK_CHAR);}
	YY_BREAK


case 85:
YY_RULE_SETUP
#line 172 "../../kmflcomp/src/lex.l"
{/* ignore */}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 173 "../../kmflcomp/src/lex.l"
{ return(TOK_COMMA);}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 174 "../../kmflcomp/src/lex.l"
{ return(TOK_BRKT);}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 175 "../../kmflcomp/src/lex.l"
{BEGIN(caller);return(TOK_BRKT);}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 176 "../../kmflcomp/src/lex.l"
{yylval.number=*yytext;return(TOK_CHAR);}
	YY_BREAK


case 90:
YY_RULE_SETUP
#line 180 "../../kmflcomp/src/lex.l"
{yylval.number=*yytext;return(TOK_CHAR);}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 181 "../../kmflcomp/src/lex.l"
{BEGIN(caller);}
	YY_BREAK


case 92:
YY_RULE_SETUP
#line 185 "../../kmflcomp/src/lex.l"
{/* ignore */}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 186 "../../kmflcomp/src/lex.l"
{yylval.number=KS_LSHIFT;return(TOK_SHIFT);}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 187 "../../kmflcomp/src/lex.l"
{yylval.number=KS_CAPS;return(TOK_SHIFT);}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 188 "../../kmflcomp/src/lex.l"
{yylval.number=KS_LCTRL;return(TOK_SHIFT);}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 189 "../../kmflcomp/src/lex.l"
{yylval.number=KS_LALT;return(TOK_SHIFT);}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 190 "../../kmflcomp/src/lex.l"
{yylval.number=KS_RSHIFT;return(TOK_SHIFT);}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 191 "../../kmflcomp/src/lex.l"
{yylval.number=KS_NCAPS;return(TOK_SHIFT);}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 192 "../../kmflcomp/src/lex.l"
{yylval.number=KS_RCTRL;return(TOK_SHIFT);}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 193 "../../kmflcomp/src/lex.l"
{yylval.number=KS_RALT;return(TOK_SHIFT);}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 194 "../../kmflcomp/src/lex.l"
{yylval.number=KS_SHIFT;return(TOK_SHIFT);}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 195 "../../kmflcomp/src/lex.l"
{yylval.number=KS_CTRL;return(TOK_SHIFT);}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 196 "../../kmflcomp/src/lex.l"
{yylval.number=KS_ALT;return(TOK_SHIFT);}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 198 "../../kmflcomp/src/lex.l"
{yylval.number=0x20;return(TOK_RAWKEY);}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 199 "../../kmflcomp/src/lex.l"
{yylval.number=0x27;return(TOK_RAWKEY);}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 200 "../../kmflcomp/src/lex.l"
{yylval.number=0x30;return(TOK_RAWKEY);}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 201 "../../kmflcomp/src/lex.l"
{yylval.number=0x31;return(TOK_RAWKEY);}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 202 "../../kmflcomp/src/lex.l"
{yylval.number=0x32;return(TOK_RAWKEY);}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 203 "../../kmflcomp/src/lex.l"
{yylval.number=0x33;return(TOK_RAWKEY);}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 204 "../../kmflcomp/src/lex.l"
{yylval.number=0x34;return(TOK_RAWKEY);}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 205 "../../kmflcomp/src/lex.l"
{yylval.number=0x35;return(TOK_RAWKEY);}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 206 "../../kmflcomp/src/lex.l"
{yylval.number=0x36;return(TOK_RAWKEY);}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 207 "../../kmflcomp/src/lex.l"
{yylval.number=0x37;return(TOK_RAWKEY);}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 208 "../../kmflcomp/src/lex.l"
{yylval.number=0x38;return(TOK_RAWKEY);}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 209 "../../kmflcomp/src/lex.l"
{yylval.number=0x39;return(TOK_RAWKEY);}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 210 "../../kmflcomp/src/lex.l"
{yylval.number=0x41;return(TOK_RAWKEY);}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 211 "../../kmflcomp/src/lex.l"
{yylval.number=0x42;return(TOK_RAWKEY);}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 212 "../../kmflcomp/src/lex.l"
{yylval.number=0x43;return(TOK_RAWKEY);}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 213 "../../kmflcomp/src/lex.l"
{yylval.number=0x44;return(TOK_RAWKEY);}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 214 "../../kmflcomp/src/lex.l"
{yylval.number=0x45;return(TOK_RAWKEY);}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 215 "../../kmflcomp/src/lex.l"
{yylval.number=0x46;return(TOK_RAWKEY);}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 216 "../../kmflcomp/src/lex.l"
{yylval.number=0x47;return(TOK_RAWKEY);}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 217 "../../kmflcomp/src/lex.l"
{yylval.number=0x48;return(TOK_RAWKEY);}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 218 "../../kmflcomp/src/lex.l"
{yylval.number=0x49;return(TOK_RAWKEY);}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 219 "../../kmflcomp/src/lex.l"
{yylval.number=0x4a;return(TOK_RAWKEY);}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 220 "../../kmflcomp/src/lex.l"
{yylval.number=0x4b;return(TOK_RAWKEY);}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 221 "../../kmflcomp/src/lex.l"
{yylval.number=0x4c;return(TOK_RAWKEY);}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 222 "../../kmflcomp/src/lex.l"
{yylval.number=0x4d;return(TOK_RAWKEY);}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 223 "../../kmflcomp/src/lex.l"
{yylval.number=0x4e;return(TOK_RAWKEY);}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 224 "../../kmflcomp/src/lex.l"
{yylval.number=0x4f;return(TOK_RAWKEY);}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 225 "../../kmflcomp/src/lex.l"
{yylval.number=0x50;return(TOK_RAWKEY);}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 226 "../../kmflcomp/src/lex.l"
{yylval.number=0x51;return(TOK_RAWKEY);}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 227 "../../kmflcomp/src/lex.l"
{yylval.number=0x52;return(TOK_RAWKEY);}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 228 "../../kmflcomp/src/lex.l"
{yylval.number=0x53;return(TOK_RAWKEY);}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 229 "../../kmflcomp/src/lex.l"
{yylval.number=0x54;return(TOK_RAWKEY);}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 230 "../../kmflcomp/src/lex.l"
{yylval.number=0x55;return(TOK_RAWKEY);}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 231 "../../kmflcomp/src/lex.l"
{yylval.number=0x56;return(TOK_RAWKEY);}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 232 "../../kmflcomp/src/lex.l"
{yylval.number=0x57;return(TOK_RAWKEY);}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 233 "../../kmflcomp/src/lex.l"
{yylval.number=0x58;return(TOK_RAWKEY);}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 234 "../../kmflcomp/src/lex.l"
{yylval.number=0x59;return(TOK_RAWKEY);}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 235 "../../kmflcomp/src/lex.l"
{yylval.number=0x5a;return(TOK_RAWKEY);}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 236 "../../kmflcomp/src/lex.l"
{yylval.number=0x60;return(TOK_RAWKEY);}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 237 "../../kmflcomp/src/lex.l"
{yylval.number=0x2c;return(TOK_RAWKEY);}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 238 "../../kmflcomp/src/lex.l"
{yylval.number=0x2d;return(TOK_RAWKEY);}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 239 "../../kmflcomp/src/lex.l"
{yylval.number=0x2e;return(TOK_RAWKEY);}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 240 "../../kmflcomp/src/lex.l"
{yylval.number=0x2f;return(TOK_RAWKEY);}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 241 "../../kmflcomp/src/lex.l"
{yylval.number=0x3a;return(TOK_RAWKEY);}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 242 "../../kmflcomp/src/lex.l"
{yylval.number=0x3d;return(TOK_RAWKEY);}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 243 "../../kmflcomp/src/lex.l"
{yylval.number=0x5b;return(TOK_RAWKEY);}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 244 "../../kmflcomp/src/lex.l"
{yylval.number=0x5c;return(TOK_RAWKEY);}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 245 "../../kmflcomp/src/lex.l"
{yylval.number=0x5d;return(TOK_RAWKEY);}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 246 "../../kmflcomp/src/lex.l"
{yylval.number=0xff08;return(TOK_RAWKEY);}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 247 "../../kmflcomp/src/lex.l"
{yylval.number=0xff09;return(TOK_RAWKEY);}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 248 "../../kmflcomp/src/lex.l"
{yylval.number=0xff0d;return(TOK_RAWKEY);}
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 249 "../../kmflcomp/src/lex.l"
{yylval.number=0xff13;return(TOK_RAWKEY);}
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 250 "../../kmflcomp/src/lex.l"
{yylval.number=0xff14;return(TOK_RAWKEY);}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 251 "../../kmflcomp/src/lex.l"
{yylval.number=0xff1b;return(TOK_RAWKEY);}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 252 "../../kmflcomp/src/lex.l"
{yylval.number=0xff50;return(TOK_RAWKEY);}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 253 "../../kmflcomp/src/lex.l"
{yylval.number=0xff51;return(TOK_RAWKEY);}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 254 "../../kmflcomp/src/lex.l"
{yylval.number=0xff52;return(TOK_RAWKEY);}
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 255 "../../kmflcomp/src/lex.l"
{yylval.number=0xff53;return(TOK_RAWKEY);}
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 256 "../../kmflcomp/src/lex.l"
{yylval.number=0xff54;return(TOK_RAWKEY);}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 257 "../../kmflcomp/src/lex.l"
{yylval.number=0xff55;return(TOK_RAWKEY);}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 258 "../../kmflcomp/src/lex.l"
{yylval.number=0xff56;return(TOK_RAWKEY);}
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 259 "../../kmflcomp/src/lex.l"
{yylval.number=0xff57;return(TOK_RAWKEY);}
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 260 "../../kmflcomp/src/lex.l"
{yylval.number=0xff63;return(TOK_RAWKEY);}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 261 "../../kmflcomp/src/lex.l"
{yylval.number=0xff7f;return(TOK_RAWKEY);}
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 262 "../../kmflcomp/src/lex.l"
{yylval.number=0xffaa;return(TOK_RAWKEY);}
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 263 "../../kmflcomp/src/lex.l"
{yylval.number=0xffab;return(TOK_RAWKEY);}
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 264 "../../kmflcomp/src/lex.l"
{yylval.number=0xffad;return(TOK_RAWKEY);}
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 265 "../../kmflcomp/src/lex.l"
{yylval.number=0xffae;return(TOK_RAWKEY);}
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 266 "../../kmflcomp/src/lex.l"
{yylval.number=0xffaf;return(TOK_RAWKEY);}
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 267 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb0;return(TOK_RAWKEY);}
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 268 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb1;return(TOK_RAWKEY);}
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 269 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb2;return(TOK_RAWKEY);}
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 270 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb3;return(TOK_RAWKEY);}
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 271 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb4;return(TOK_RAWKEY);}
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 272 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb5;return(TOK_RAWKEY);}
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 273 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb6;return(TOK_RAWKEY);}
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 274 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb7;return(TOK_RAWKEY);}
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 275 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb8;return(TOK_RAWKEY);}
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 276 "../../kmflcomp/src/lex.l"
{yylval.number=0xffb9;return(TOK_RAWKEY);}
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 277 "../../kmflcomp/src/lex.l"
{yylval.number=0xffbe;return(TOK_RAWKEY);}
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 278 "../../kmflcomp/src/lex.l"
{yylval.number=0xffbf;return(TOK_RAWKEY);}
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 279 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc0;return(TOK_RAWKEY);}
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 280 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc1;return(TOK_RAWKEY);}
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 281 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc2;return(TOK_RAWKEY);}
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 282 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc3;return(TOK_RAWKEY);}
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 283 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc4;return(TOK_RAWKEY);}
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 284 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc5;return(TOK_RAWKEY);}
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 285 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc6;return(TOK_RAWKEY);}
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 286 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc7;return(TOK_RAWKEY);}
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 287 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc8;return(TOK_RAWKEY);}
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 288 "../../kmflcomp/src/lex.l"
{yylval.number=0xffc9;return(TOK_RAWKEY);}
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 289 "../../kmflcomp/src/lex.l"
{yylval.number=0xffca;return(TOK_RAWKEY);}
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 290 "../../kmflcomp/src/lex.l"
{yylval.number=0xffcb;return(TOK_RAWKEY);}
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 291 "../../kmflcomp/src/lex.l"
{yylval.number=0xffcc;return(TOK_RAWKEY);}
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 292 "../../kmflcomp/src/lex.l"
{yylval.number=0xffcd;return(TOK_RAWKEY);}
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 293 "../../kmflcomp/src/lex.l"
{yylval.number=0xffce;return(TOK_RAWKEY);}
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 294 "../../kmflcomp/src/lex.l"
{yylval.number=0xffcf;return(TOK_RAWKEY);}
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 295 "../../kmflcomp/src/lex.l"
{yylval.number=0xffd0;return(TOK_RAWKEY);}
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 296 "../../kmflcomp/src/lex.l"
{yylval.number=0xffd1;return(TOK_RAWKEY);}
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 297 "../../kmflcomp/src/lex.l"
{yylval.number=0xffd2;return(TOK_RAWKEY);}
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 298 "../../kmflcomp/src/lex.l"
{yylval.number=0xffd3;return(TOK_RAWKEY);}
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 299 "../../kmflcomp/src/lex.l"
{yylval.number=0xffd4;return(TOK_RAWKEY);}
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 300 "../../kmflcomp/src/lex.l"
{yylval.number=0xffd5;return(TOK_RAWKEY);}
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 301 "../../kmflcomp/src/lex.l"
{yylval.number=0xffe1;return(TOK_RAWKEY);}
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 302 "../../kmflcomp/src/lex.l"
{yylval.number=0xffe3;return(TOK_RAWKEY);}
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 303 "../../kmflcomp/src/lex.l"
{yylval.number=0xffe5;return(TOK_RAWKEY);}
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 304 "../../kmflcomp/src/lex.l"
{yylval.number=0xffe9;return(TOK_RAWKEY);}
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 305 "../../kmflcomp/src/lex.l"
{yylval.number=0xffff;return(TOK_RAWKEY);}
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 306 "../../kmflcomp/src/lex.l"
{yylval.number=0x3c;return(TOK_RAWKEY); /* on German kbds only!*/}
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 308 "../../kmflcomp/src/lex.l"
{yylval.number=text_to_keysym(yytext); if (yylval.number == -1) yyerror("unrecognised raw key"); else return(TOK_XKEYSYM);}
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 309 "../../kmflcomp/src/lex.l"
{ yyerror("unrecognised raw key");} 
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 310 "../../kmflcomp/src/lex.l"
{caller0=caller;caller=KEYNAME;qchar='\'';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 311 "../../kmflcomp/src/lex.l"
{caller0=caller;caller=KEYNAME;qchar='\"';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 313 "../../kmflcomp/src/lex.l"
{
					if(caller==KEYNAME) caller=caller0;
					BEGIN(caller);return(TOK_SB);
				} 
	YY_BREAK

case 218:
/* rule 218 can match eol */
YY_RULE_SETUP
#line 319 "../../kmflcomp/src/lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 219:
/* rule 219 can match eol */
YY_RULE_SETUP
#line 320 "../../kmflcomp/src/lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 220:
/* rule 220 can match eol */
YY_RULE_SETUP
#line 321 "../../kmflcomp/src/lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 221:
/* rule 221 can match eol */
YY_RULE_SETUP
#line 322 "../../kmflcomp/src/lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 222:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 324 "../../kmflcomp/src/lex.l"
{/* ignore, use both /\r and /\n, not to work $ */}
	YY_BREAK
case 223:
/* rule 223 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 325 "../../kmflcomp/src/lex.l"
{/*   with either CR or CR/LF line ending */}
	YY_BREAK
case 224:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 326 "../../kmflcomp/src/lex.l"
{/* ignore */}
	YY_BREAK
case 225:
/* rule 225 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 327 "../../kmflcomp/src/lex.l"
{/* ignore */}
	YY_BREAK
case 226:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 328 "../../kmflcomp/src/lex.l"
{/* ignore */}
	YY_BREAK
case 227:
/* rule 227 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 329 "../../kmflcomp/src/lex.l"
{/* ignore */}
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 331 "../../kmflcomp/src/lex.l"
{BEGIN(SKIP);}
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 333 "../../kmflcomp/src/lex.l"
{/* Keyman platform conditional - just drop marker */}
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 334 "../../kmflcomp/src/lex.l"
{/* Kmfl platform conditional - just drop marker */}
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 335 "../../kmflcomp/src/lex.l"
{BEGIN(SKIP);} /* Platform Conditional */
	YY_BREAK

case 232:
YY_RULE_SETUP
#line 338 "../../kmflcomp/src/lex.l"
{/* ignore everything until nl or EOF */}
	YY_BREAK

case 233:
YY_RULE_SETUP
#line 341 "../../kmflcomp/src/lex.l"
{fprintf(stderr,"Line %d: Unmatched closing parenthesis\n",lineno);return(TOK_BRKT);}
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 342 "../../kmflcomp/src/lex.l"
{yylval.number=yytext[0];fprintf(stderr,"Line %d: Unrecognized keyword '%s'\n", 
					(int)lineno, yytext);errcount++;return(TOK_ERROR);}
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 344 "../../kmflcomp/src/lex.l"
{yylval.number=yytext[0];fprintf(stderr,"Line %d: Unexpected char (%d) `%c'\n", 
					(int)lineno, (int) yytext[0],(char) yytext[0]);errcount++;return(TOK_CHAR);}
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 346 "../../kmflcomp/src/lex.l"
ECHO;
	YY_BREAK
#line 2804 "lex.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 773 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 773 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 772);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 346 "../../kmflcomp/src/lex.l"
